@@ -180,10 +180,10 @@ pub fn activity_ui(
         }
     }
 
-    if let Some(index) = table_data.state.selected() {
-        if index > 10 {
-            *table_data.state.offset_mut() = index - 10;
-        }
+    if let Some(index) = table_data.state.selected()
+        && index > 10
+    {
+        *table_data.state.offset_mut() = index - 10;
     }
 
     f.render_widget(year_tab, chunks[0]);
