@@ -2,4 +2,4 @@ mod home_data;
 mod home_ui;
 
 pub use home_data::TransactionData;
-pub use home_ui::{home_ui, BALANCE_BOLD};
+pub use home_ui::{BALANCE_BOLD, home_ui};
