@@ -11,13 +11,14 @@ struct GithubRelease {
     body: String,
 }
 
-/// Uses Github API to get the latest release version number to check if the current version matches with it.
+/// Uses GitHub API to get the latest release version number to check if the current version matches with it.
 #[cfg(not(tarpaulin_include))]
 pub fn check_version() -> Result<Option<Vec<String>>, Error> {
     let current_version = Version::parse(env!("CARGO_PKG_VERSION")).unwrap();
 
     let client = reqwest::blocking::Client::builder()
         .user_agent("Rex")
+        .connect_timeout(Duration::from_secs(1))
         .timeout(Duration::from_secs(2))
         .build()?;
 
