@@ -131,6 +131,9 @@ pub fn start_app<B: Backend>(
         summary_years.index,
     ));
 
+    let mut last_summary_methods = None;
+    let mut last_summary_net = None;
+
     // Data for the Search Page's table
     let mut search_table = TableData::new(Vec::new());
 
@@ -239,6 +242,8 @@ pub fn start_app<B: Backend>(
                         summary_hidden_mode,
                         &summary_sort,
                         &mut lerp_state,
+                        &last_summary_methods,
+                        &last_summary_net,
                         conn,
                     ),
                     CurrentUi::Search => search_ui(
@@ -342,6 +347,8 @@ pub fn start_app<B: Backend>(
                 &mut popup_scroll_position,
                 &mut max_popup_scroll,
                 &mut lerp_state,
+                &mut last_summary_methods,
+                &mut last_summary_net,
                 conn,
             );
 
