@@ -1,5 +1,5 @@
 mod popup_data;
 mod popup_ui;
 
-pub use popup_data::{PopupData, A, F, H, Q, R, V, W, Y, Z};
+pub use popup_data::{A, F, H, PopupData, Q, R, V, W, Y, Z};
 pub use popup_ui::{create_deletion_popup, create_popup};
