@@ -9,7 +9,12 @@ use crate::page_handler::{
     BACKGROUND, BOX, HEADER, IndexedData, SELECTED, SortingType, SummaryTab, TEXT, TableData,
 };
 use crate::summary_page::SummaryData;
-use crate::utility::{LerpState, create_tab, get_all_tx_methods, main_block, styled_block};
+#[cfg(not(tarpaulin_include))]
+use crate::summary_page::{SummaryMethods, SummaryNet};
+use crate::utility::{
+    LerpState, create_tab, get_all_tx_methods, main_block, styled_block, styled_block_no_bottom,
+    styled_block_no_top,
+};
 
 /// The function draws the Summary page of the interface.
 #[cfg(not(tarpaulin_include))]
@@ -24,16 +29,18 @@ pub fn summary_ui(
     summary_hidden_mode: bool,
     summary_sort: &SortingType,
     lerp_state: &mut LerpState,
+    last_summary_methods: &Option<Vec<SummaryMethods>>,
+    last_summary_net: &Option<SummaryNet>,
     conn: &Connection,
 ) {
-    let (summary_data_1, summary_data_2, summary_data_3, summary_data_4, method_data) =
-        summary_data.get_tx_data(mode_selection, months.index, years.index, conn);
-
-    let mut summary_table_1 = TableData::new(summary_data_1);
-    let mut summary_table_2 = TableData::new(summary_data_2);
-    let mut summary_table_3 = TableData::new(summary_data_3);
-    let mut summary_table_4 = TableData::new(summary_data_4);
-    let mut method_table = TableData::new(method_data);
+    let (summary_net, summary_largest, summary_peak, summary_methods) = summary_data.get_tx_data(
+        mode_selection,
+        months.index,
+        years.index,
+        last_summary_methods,
+        last_summary_net,
+        conn,
+    );
 
     let size = f.area();
 
@@ -55,27 +62,47 @@ pub fn summary_ui(
         "Total Expense"
     };
 
-    let header_cells = [
+    let mut table_headers = vec![
         tag_header,
         total_income_header,
         total_expense_header,
         "Income %",
         "Expense %",
-    ]
-    .into_iter()
-    .map(|h| Cell::from(h).style(Style::default().fg(BACKGROUND)));
+    ];
 
-    let method_header_cells = [
-        "Method",
-        "Total Income",
-        "Total Expense",
-        "Income %",
-        "Expense %",
-        "Average Income",
-        "Average Expense",
-    ]
-    .iter()
-    .map(|h| Cell::from(*h).style(Style::default().fg(BACKGROUND)));
+    if mode_selection.index == 0 {
+        table_headers.push("MoM Income %");
+        table_headers.push("MoM Expense %");
+    } else if mode_selection.index == 1 {
+        table_headers.push("YoY Income %");
+        table_headers.push("YoY Expense %");
+    }
+
+    let header_cells = table_headers
+        .into_iter()
+        .map(|h| Cell::from(h).style(Style::default().fg(BACKGROUND)));
+
+    let mut method_headers = vec!["Method", "Total Income", "Total Expense"];
+
+    if mode_selection.index != 0 {
+        method_headers.push("Average Income");
+        method_headers.push("Average Expense");
+    }
+
+    method_headers.push("Income %");
+    method_headers.push("Expense %");
+
+    if mode_selection.index == 0 {
+        method_headers.push("MoM Income %");
+        method_headers.push("MoM Expense %");
+    } else if mode_selection.index == 1 {
+        method_headers.push("YoY Income %");
+        method_headers.push("YoY Expense %");
+    }
+
+    let method_header_cells = method_headers
+        .iter()
+        .map(|h| Cell::from(*h).style(Style::default().fg(BACKGROUND)));
 
     let header = Row::new(header_cells)
         .style(Style::default().bg(HEADER))
@@ -94,8 +121,9 @@ pub fn summary_ui(
 
     if summary_hidden_mode {
         main_layout = main_layout.constraints([
-            Constraint::Length(method_len + 3),
-            Constraint::Length(9),
+            Constraint::Length(method_len + 2),
+            Constraint::Length(3),
+            Constraint::Length(4),
             Constraint::Min(0),
         ]);
         summary_layout =
@@ -107,8 +135,9 @@ pub fn summary_ui(
                     Constraint::Length(3),
                     Constraint::Length(3),
                     Constraint::Length(3),
-                    Constraint::Length(method_len + 3),
-                    Constraint::Length(9),
+                    Constraint::Length(method_len + 2),
+                    Constraint::Length(3),
+                    Constraint::Length(4),
                     Constraint::Min(0),
                 ]);
                 summary_layout = summary_layout
@@ -118,8 +147,9 @@ pub fn summary_ui(
                 main_layout = main_layout.constraints([
                     Constraint::Length(3),
                     Constraint::Length(3),
-                    Constraint::Length(method_len + 3),
-                    Constraint::Length(9),
+                    Constraint::Length(method_len + 2),
+                    Constraint::Length(3),
+                    Constraint::Length(4),
                     Constraint::Min(0),
                 ]);
                 summary_layout = summary_layout
@@ -128,12 +158,13 @@ pub fn summary_ui(
             2 => {
                 main_layout = main_layout.constraints([
                     Constraint::Length(3),
-                    Constraint::Length(method_len + 3),
-                    Constraint::Length(9),
+                    Constraint::Length(method_len + 2),
+                    Constraint::Length(3),
+                    Constraint::Length(4),
                     Constraint::Min(0),
                 ]);
                 summary_layout = summary_layout
-                    .constraints([Constraint::Percentage(50), Constraint::Percentage(50)]);
+                    .constraints([Constraint::Percentage(100), Constraint::Percentage(50)]);
             }
             _ => {}
         }
@@ -141,21 +172,11 @@ pub fn summary_ui(
 
     let chunks = main_layout.split(size);
     let summary_chunk = if summary_hidden_mode {
-        summary_layout.split(chunks[1])
+        summary_layout.split(chunks[2])
     } else {
-        summary_layout.split(chunks[4 - mode_selection.index])
+        summary_layout.split(chunks[5 - mode_selection.index])
     };
 
-    let left_summary = Layout::default()
-        .direction(Direction::Vertical)
-        .constraints([Constraint::Percentage(60), Constraint::Percentage(40)])
-        .split(summary_chunk[0]);
-
-    let right_summary = Layout::default()
-        .direction(Direction::Vertical)
-        .constraints([Constraint::Percentage(60), Constraint::Percentage(40)])
-        .split(summary_chunk[1]);
-
     f.render_widget(main_block(), size);
 
     let mut month_tab = create_tab(months, "Months");
@@ -172,6 +193,26 @@ pub fn summary_ui(
         .map(|(row_index, item)| {
             let cells = item.iter().enumerate().map(|(index, c)| {
                 let Ok(parsed_num) = c.parse::<f64>() else {
+                    if c == "∞" {
+                        let lerp_id = format!("summary_table_main:{index}:{row_index}");
+                        lerp_state.lerp(&lerp_id, 0.0);
+                    }
+
+                    let symbol = if c.contains('↑') || c.contains('↓') {
+                        c.chars().next()
+                    } else {
+                        None
+                    };
+
+                    if let Some(sym) = symbol {
+                        let c = c.replace(sym, "");
+                        if let Ok(parsed_num) = c.parse::<f64>() {
+                            let lerp_id = format!("summary_table_main:{index}:{row_index}");
+                            let new_c = lerp_state.lerp(&lerp_id, parsed_num);
+
+                            return Cell::from(format!("{sym}{new_c:.2}").separate_with_commas());
+                        }
+                    }
                     return Cell::from(c.separate_with_commas());
                 };
 
@@ -186,72 +227,38 @@ pub fn summary_ui(
                 .style(Style::default().fg(TEXT))
         });
 
-    let mut table_area = Table::new(
-        rows,
-        [
+    let table_width = if mode_selection.index == 2 {
+        vec![
             Constraint::Percentage(20),
             Constraint::Percentage(20),
             Constraint::Percentage(20),
             Constraint::Percentage(20),
             Constraint::Percentage(20),
-        ],
-    )
-    .header(header)
-    .block(styled_block("Tags"))
-    .style(Style::default().fg(BOX));
+        ]
+    } else {
+        vec![
+            Constraint::Percentage(14),
+            Constraint::Percentage(14),
+            Constraint::Percentage(14),
+            Constraint::Percentage(14),
+            Constraint::Percentage(14),
+            Constraint::Percentage(14),
+            Constraint::Percentage(15),
+        ]
+    };
 
-    let summary_rows_1 = summary_table_1
-        .items
-        .iter()
+    let mut table_area = Table::new(rows, table_width)
+        .header(header)
+        .block(styled_block("Tags"))
+        .style(Style::default().fg(BOX));
+
+    let summary_rows_largest = summary_largest
+        .into_iter()
         .enumerate()
         .map(|(row_index, item)| {
-            let cells = item.iter().enumerate().map(|(index, c)| {
+            let cells = item.array().into_iter().enumerate().map(|(index, c)| {
                 let mut cell = if let Ok(parsed_num) = c.parse::<f64>() {
-                    let lerp_id = format!("summary_table_1:{index}:{row_index}");
-                    let new_c = lerp_state.lerp(&lerp_id, parsed_num);
-
-                    let text = if index == 2 {
-                        // Total income/expense % column. Add % char manually
-                        format!("{new_c:.2}%").separate_with_commas()
-                    } else {
-                        format!("{new_c:.2}").separate_with_commas()
-                    };
-
-                    Cell::from(text)
-                } else {
-                    Cell::from(c.separate_with_commas())
-                };
-
-                if index == 0 {
-                    cell = cell.style(Style::default().fg(TEXT).add_modifier(Modifier::BOLD));
-                }
-                cell
-            });
-            Row::new(cells)
-                .height(1)
-                .bottom_margin(0)
-                .style(Style::default().fg(TEXT))
-        });
-
-    let summary_area_1 = Table::new(
-        summary_rows_1,
-        [
-            Constraint::Percentage(33),
-            Constraint::Percentage(33),
-            Constraint::Percentage(33),
-        ],
-    )
-    .block(styled_block(""))
-    .style(Style::default().fg(BOX));
-
-    let summary_rows_2 = summary_table_2
-        .items
-        .iter()
-        .enumerate()
-        .map(|(row_index, item)| {
-            let cells = item.iter().enumerate().map(|(index, c)| {
-                let mut cell = if let Ok(parsed_num) = c.parse::<f64>() {
-                    let lerp_id = format!("summary_table_2:{index}:{row_index}");
+                    let lerp_id = format!("summary_table_largest:{index}:{row_index}");
                     let new_c = lerp_state.lerp(&lerp_id, parsed_num);
 
                     Cell::from(format!("{new_c:.2}").separate_with_commas())
@@ -270,26 +277,26 @@ pub fn summary_ui(
                 .style(Style::default().fg(TEXT))
         });
 
-    let summary_area_2 = Table::new(
-        summary_rows_2,
+    let summary_area_largest = Table::new(
+        summary_rows_largest,
         [
-            Constraint::Percentage(33),
-            Constraint::Percentage(33),
-            Constraint::Percentage(33),
+            Constraint::Percentage(25),
+            Constraint::Percentage(25),
+            Constraint::Percentage(25),
+            Constraint::Percentage(25),
         ],
     )
     .block(styled_block(""))
     .style(Style::default().fg(BOX));
 
-    let summary_rows_3 = summary_table_3
-        .items
-        .iter()
+    let summary_rows_peak = summary_peak
+        .into_iter()
         .enumerate()
         .map(|(row_index, item)| {
             let height = 1;
-            let cells = item.iter().enumerate().map(|(index, c)| {
+            let cells = item.array().into_iter().enumerate().map(|(index, c)| {
                 let mut cell = if let Ok(parsed_num) = c.parse::<f64>() {
-                    let lerp_id = format!("summary_table_3:{index}:{row_index}");
+                    let lerp_id = format!("summary_table_peak:{index}:{row_index}");
                     let new_c = lerp_state.lerp(&lerp_id, parsed_num);
 
                     let text = if index == 1 && row_index == 2 {
@@ -316,68 +323,48 @@ pub fn summary_ui(
                 .style(Style::default().fg(TEXT))
         });
 
-    let summary_area_3 = Table::new(
-        summary_rows_3,
+    let summary_area_peak = Table::new(
+        summary_rows_peak,
         [
-            Constraint::Percentage(25),
-            Constraint::Percentage(25),
-            Constraint::Percentage(25),
-            Constraint::Percentage(25),
+            Constraint::Percentage(33),
+            Constraint::Percentage(33),
+            Constraint::Percentage(33),
         ],
     )
     .block(styled_block(""))
     .style(Style::default().fg(BOX));
 
-    let summary_rows_4 = summary_table_4
-        .items
-        .iter()
+    let method_rows = summary_methods
+        .into_iter()
         .enumerate()
         .map(|(row_index, item)| {
-            let cells = item.iter().enumerate().map(|(index, c)| {
-                let mut cell = if let Ok(parsed_num) = c.parse::<f64>() {
-                    let lerp_id = format!("summary_table_4:{index}:{row_index}");
-                    let new_c = lerp_state.lerp(&lerp_id, parsed_num);
-
-                    Cell::from(format!("{new_c:.2}").separate_with_commas())
-                } else {
-                    Cell::from(c.separate_with_commas())
-                };
-
-                if index == 0 {
-                    cell = cell.style(Style::default().fg(TEXT).add_modifier(Modifier::BOLD));
-                }
-                cell
-            });
-            Row::new(cells)
-                .height(1)
-                .bottom_margin(0)
-                .style(Style::default().fg(TEXT))
-        });
-
-    let summary_area_4 = Table::new(
-        summary_rows_4,
-        [
-            Constraint::Percentage(25),
-            Constraint::Percentage(25),
-            Constraint::Percentage(25),
-            Constraint::Percentage(25),
-        ],
-    )
-    .block(styled_block(""))
-    .style(Style::default().fg(BOX));
-
-    let method_rows = method_table
-        .items
-        .iter()
-        .enumerate()
-        .map(|(row_index, item)| {
-            let cells = item.iter().enumerate().map(|(index, c)| {
+            let cells = item.array().into_iter().enumerate().map(|(index, c)| {
                 let mut cell = if let Ok(parsed_num) = c.parse::<f64>() {
                     let lerp_id = format!("method_table:{index}:{row_index}");
                     let new_c = lerp_state.lerp(&lerp_id, parsed_num);
 
                     Cell::from(format!("{new_c:.2}").separate_with_commas())
                 } else {
+                    let symbol = if c.contains('↑') || c.contains('↓') {
+                        c.chars().next()
+                    } else {
+                        None
+                    };
+
+                    if let Some(sym) = symbol {
+                        let c = c.replace(sym, "");
+                        if let Ok(parsed_num) = c.parse::<f64>() {
+                            let lerp_id = format!("method_table:{index}:{row_index}");
+                            let new_c = lerp_state.lerp(&lerp_id, parsed_num);
+
+                            return Cell::from(format!("{sym}{new_c:.2}").separate_with_commas());
+                        }
+                    }
+
+                    if c == "∞" {
+                        let lerp_id = format!("method_table:{index}:{row_index}");
+                        lerp_state.lerp(&lerp_id, 0.0);
+                    }
                     Cell::from(c.separate_with_commas())
                 };
 
@@ -392,21 +379,94 @@ pub fn summary_ui(
                 .style(Style::default().fg(TEXT))
         });
 
-    let method_area = Table::new(
-        method_rows,
-        [
+    let method_widths = if mode_selection.index == 2 {
+        vec![
+            Constraint::Percentage(10),
             Constraint::Percentage(14),
             Constraint::Percentage(14),
             Constraint::Percentage(14),
             Constraint::Percentage(14),
+            Constraint::Percentage(16),
+            Constraint::Percentage(16),
+        ]
+    } else if mode_selection.index == 1 {
+        vec![
+            Constraint::Percentage(10),
+            Constraint::Percentage(12),
+            Constraint::Percentage(12),
+            Constraint::Percentage(10),
+            Constraint::Percentage(10),
+            Constraint::Percentage(12),
+            Constraint::Percentage(12),
+            Constraint::Percentage(10),
+            Constraint::Percentage(10),
+        ]
+    } else {
+        vec![
+            Constraint::Percentage(10),
             Constraint::Percentage(14),
             Constraint::Percentage(14),
             Constraint::Percentage(14),
-        ],
-    )
-    .header(method_header)
-    .block(styled_block(""))
-    .style(Style::default().fg(BOX));
+            Constraint::Percentage(14),
+            Constraint::Percentage(16),
+            Constraint::Percentage(16),
+        ]
+    };
+
+    let method_area = Table::new(method_rows, &method_widths)
+        .header(method_header)
+        .block(styled_block_no_bottom(""))
+        .style(Style::default().fg(BOX));
+
+    let net_row = summary_net
+        .array()
+        .into_iter()
+        .enumerate()
+        .map(|(row_index, item)| {
+            let cells = item.iter().enumerate().map(|(index, c)| {
+                let mut cell = if let Ok(parsed_num) = c.parse::<f64>() {
+                    let lerp_id = format!("summary_rows_net:{index}:{row_index}");
+                    let new_c = lerp_state.lerp(&lerp_id, parsed_num);
+
+                    Cell::from(format!("{new_c:.2}").separate_with_commas())
+                } else {
+                    if c == "∞" {
+                        let lerp_id = format!("summary_rows_net:{index}:{row_index}");
+                        lerp_state.lerp(&lerp_id, 0.0);
+                    }
+
+                    let symbol = if c.contains('↑') || c.contains('↓') {
+                        c.chars().next()
+                    } else {
+                        None
+                    };
+
+                    if let Some(sym) = symbol {
+                        let c = c.replace(sym, "");
+                        if let Ok(parsed_num) = c.parse::<f64>() {
+                            let lerp_id = format!("summary_table_main:{index}:{row_index}");
+                            let new_c = lerp_state.lerp(&lerp_id, parsed_num);
+
+                            return Cell::from(format!("{sym}{new_c:.2}").separate_with_commas());
+                        }
+                    }
+                    Cell::from(c.separate_with_commas())
+                };
+
+                if index == 0 {
+                    cell = cell.style(Style::default().fg(TEXT).add_modifier(Modifier::BOLD));
+                }
+                cell
+            });
+            Row::new(cells)
+                .height(1)
+                .bottom_margin(0)
+                .style(Style::default().fg(TEXT))
+        });
+
+    let net_area = Table::new(net_row, &method_widths)
+        .block(styled_block_no_top(""))
+        .style(Style::default().fg(BOX));
 
     match current_page {
         // Previously added a black block to year and month widget if a value is not selected
@@ -432,41 +492,40 @@ pub fn summary_ui(
     }
 
     // Always keep some items rendered on the upper side of the table
-    if let Some(index) = table_data.state.selected() {
-        if index > 7 {
-            *table_data.state.offset_mut() = index - 7;
-        }
+    if let Some(index) = table_data.state.selected()
+        && index > 7
+    {
+        *table_data.state.offset_mut() = index - 7;
     }
 
+    f.render_widget(summary_area_largest, summary_chunk[1]);
+    f.render_widget(summary_area_peak, summary_chunk[0]);
+
     if summary_hidden_mode {
-        f.render_stateful_widget(summary_area_1, left_summary[0], &mut summary_table_1.state);
-        f.render_stateful_widget(summary_area_2, left_summary[1], &mut summary_table_2.state);
-        f.render_stateful_widget(summary_area_3, right_summary[0], &mut summary_table_3.state);
-        f.render_stateful_widget(summary_area_4, right_summary[1], &mut summary_table_4.state);
-        f.render_stateful_widget(table_area, chunks[2], &mut table_data.state);
-        f.render_stateful_widget(method_area, chunks[0], &mut method_table.state);
+        f.render_widget(table_area, chunks[3]);
+        f.render_widget(net_area, chunks[1]);
+        f.render_widget(method_area, chunks[0]);
     } else {
         f.render_widget(mode_selection_tab, chunks[0]);
-        f.render_stateful_widget(summary_area_1, left_summary[0], &mut summary_table_1.state);
-        f.render_stateful_widget(summary_area_2, left_summary[1], &mut summary_table_2.state);
-        f.render_stateful_widget(summary_area_3, right_summary[0], &mut summary_table_3.state);
-        f.render_stateful_widget(summary_area_4, right_summary[1], &mut summary_table_4.state);
 
         match mode_selection.index {
             0 => {
                 f.render_widget(year_tab, chunks[1]);
                 f.render_widget(month_tab, chunks[2]);
-                f.render_stateful_widget(table_area, chunks[5], &mut table_data.state);
-                f.render_stateful_widget(method_area, chunks[3], &mut method_table.state);
+                f.render_stateful_widget(table_area, chunks[6], &mut table_data.state);
+                f.render_widget(net_area, chunks[4]);
+                f.render_widget(method_area, chunks[3]);
             }
             1 => {
                 f.render_widget(year_tab, chunks[1]);
-                f.render_stateful_widget(table_area, chunks[4], &mut table_data.state);
-                f.render_stateful_widget(method_area, chunks[2], &mut method_table.state);
+                f.render_stateful_widget(table_area, chunks[5], &mut table_data.state);
+                f.render_widget(net_area, chunks[3]);
+                f.render_widget(method_area, chunks[2]);
             }
             2 => {
-                f.render_stateful_widget(table_area, chunks[3], &mut table_data.state);
-                f.render_stateful_widget(method_area, chunks[1], &mut method_table.state);
+                f.render_stateful_widget(table_area, chunks[4], &mut table_data.state);
+                f.render_widget(net_area, chunks[2]);
+                f.render_widget(method_area, chunks[1]);
             }
             _ => {}
         }
