@@ -1,6 +1,8 @@
+mod lerp;
 mod sub_func;
 pub mod traits;
 mod utils;
 
+pub use lerp::*;
 pub use sub_func::*;
 pub use utils::*;
